import { BrowserOptions, ShortcutOptions, ShortcutValue } from "./types";
export declare const shortcutKeys: (element: HTMLElement | Window) => {
    /**
     * @description Add event to element
     * @param shortcut - Required - Shortcut to trigger action. Example: "control+h" or ["control+h", "control+shift+h"]
     * @param handler - Required - Action triggered when shortcut is triggered. Example: () => console.log("hello");
     * @param options - Optional - Extra settings. Read the documentation {@link "https://www.npmjs.com/package/shortcut-keys"}
     */
    add: (shortcut: string | string[], handler: (ev: KeyboardEvent) => any, options?: Partial<ShortcutOptions>, nativeOptions?: BrowserOptions) => void;
    /**
     * @description Remove exists event to element
     * @param shortcut - Required - Shortcut to trigger action. Example: "control+h" or ["control+h", "control+shift+h"]. When there is no data, all element events will be removed.
     */
    remove: (shortcut: string) => void;
    /**
     * @description Remove all exists events
     */
    removeAll: () => void;
    /**
      * @description List all events of element
      * @returns List about shortcuts
      * @property {string} key - Shortcut to trigger action.
      * @property {Object} info - All information about the shortcut.
     */
    list: () => {
        key: string;
        info: ShortcutValue;
    }[];
};
declare global {
    interface Window {
        shortcutKeys: typeof shortcutKeys;
    }
}
